@@ -293,7 +293,7 @@ string_append(String *s, const char *data, size_t len)
 		return;
 
 	if (s->len >= SIZE_MAX - len) {
-		errno = EOVERFLOW;
+		errno = ENOMEM;
 		err(1, "realloc");
 	}
 
@@ -383,7 +383,7 @@ string_print_trimmed_multi(String *s)
 	}
 }
 
-/* Print URL, if it's a relative URL then it uses the global `baseurl`. */
+/* Print URL, if it is a relative URL then it uses the global `baseurl`. */
 static void
 printuri(char *s)
 {
@@ -409,7 +409,7 @@ printuri(char *s)
 	*e = c; /* restore NUL byte to original character */
 }
 
-/* Print URL, if it's a relative URL then it uses the global `baseurl`. */
+/* Print URL, if it is a relative URL then it uses the global `baseurl`. */
 static void
 string_print_uri(String *s)
 {
@@ -432,18 +432,23 @@ string_print_timestamp(String *s)
 		printf("%lld", t);
 }
 
-/* Convert time fields. Returns a UNIX timestamp. */
+/* Convert time fields. Returns a signed (at least) 64-bit UNIX timestamp.
+   Parameters should be passed as they are in a struct tm:
+   that is: year = year - 1900, month = month - 1. */
 static long long
 datetounix(long long year, int mon, int day, int hour, int min, int sec)
 {
-	static const int secs_through_month[] = {
+	/* seconds in a month in a regular (non-leap) year */
+	static const long secs_through_month[] = {
 		0, 31 * 86400, 59 * 86400, 90 * 86400,
 		120 * 86400, 151 * 86400, 181 * 86400, 212 * 86400,
 		243 * 86400, 273 * 86400, 304 * 86400, 334 * 86400 };
 	int is_leap = 0, cycles, centuries = 0, leaps = 0, rem;
 	long long t;
 
+	/* optimization: handle common range year 1902 up to and including 2038 */
 	if (year - 2ULL <= 136) {
+		/* amount of leap days relative to 1970: every 4 years */
 		leaps = (year - 68) >> 2;
 		if (!((year - 68) & 3)) {
 			leaps--;
@@ -451,8 +456,11 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
 		} else {
 			is_leap = 0;
 		}
-		t = 31536000 * (year - 70) + 86400 * leaps;
+		t = 31536000 * (year - 70) + (86400 * leaps); /* 365 * 86400 = 31536000 */
 	} else {
+		/* general leap year calculation:
+		   leap years occur mostly every 4 years but every 100 years
+		   a leap year is skipped unless the year is divisible by 400 */
 		cycles = (year - 100) / 400;
 		rem = (year - 100) % 400;
 		if (rem < 0) {
@@ -474,8 +482,11 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
 				is_leap = !rem;
 			}
 		}
-		leaps += 97 * cycles + 24 * centuries - is_leap;
-		t = (year - 100) * 31536000LL + leaps * 86400LL + 946684800 + 86400;
+		leaps += (97 * cycles) + (24 * centuries) - is_leap;
+
+		/* adjust 8 leap days from 1970 up to and including 2000:
+		   ((30 * 365) + 8) * 86400 = 946771200 */
+		t = ((year - 100) * 31536000LL) + (leaps * 86400LL) + 946771200LL;
 	}
 	t += secs_through_month[mon];
 	if (is_leap && mon >= 2)
@@ -613,8 +624,8 @@ parsetime(const char *s, long long *tp)
 		for (v = 0, i = 0; i < 4 && ISDIGIT((unsigned char)*s); s++, i++)
 			v = (v * 10) + (*s - '0');
 		/* obsolete short year: RFC2822 4.3 */
-		if (i <= 3)
-			v += (v >= 0 && v <= 49) ? 2000 : 1900;
+		if (i == 2 || i == 3)
+			v += (i == 2 && v >= 0 && v <= 49) ? 2000 : 1900;
 		va[0] = v; /* year */
 		for (; ISSPACE((unsigned char)*s); s++)
 			;
@@ -743,7 +754,7 @@ static void
 xmlattrentity(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl,
               const char *data, size_t datalen)
 {
-	char buf[16];
+	char buf[8];
 	int len;
 
 	/* handles transforming inline XML to data */
@@ -820,7 +831,7 @@ xmldata(XMLParser *p, const char *s, size_t len)
 static void
 xmldataentity(XMLParser *p, const char *data, size_t datalen)
 {
-	char buf[16];
+	char buf[8];
 	int len;
 
 	if (!ctx.field)
@@ -896,7 +907,7 @@ xmltagstartparsed(XMLParser *p, const char *t, size_t tl, int isshort)
 		return;
 	}
 
-	/* set tag type based on it's attribute value */
+	/* set tag type based on its attribute value */
 	if (ctx.tag.id == RSSTagGuid) {
 		/* if empty the default is "true" */
 		if (!attrispermalink.len ||
@@ -1007,7 +1018,7 @@ xmltagend(XMLParser *p, const char *t, size_t tl, int isshort)
 	}
 
 	/* temporary string: for fields that cannot be processed
-	   directly and need more context, for example by it's tag
+	   directly and need more context, for example by its tag
 	   attributes, like the Atom link rel="alternate|enclosure". */
 	if (tmpstr.len && ctx.field) {
 		if (ISFEEDFIELDMULTI(fieldmap[ctx.tag.id])) {
